#
# spec file for package netgen
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_with need_clang
%bcond_with openmpi
%bcond_without ffmpeg
%bcond_with opencascade

Name:           netgen
Version:        6.2.1810
Release:        bp153.1.29
Summary:        Automatic 3D tetrahedral mesh generator
License:        LGPL-2.1-only
Group:          Productivity/Graphics/CAD
URL:            https://ngsolve.org/
Source0:        netgen-%{version}.tar.xz
Patch0:         fix_build.patch
# PATCH-FIX-OPENSUSE -- do not try to include immintrin.h when SSE is not supported
Patch1:         0001-Allow-compilation-on-archs-beyond-x86.patch
# not supported by upstream
%if %{with opencascade}
BuildRequires:  occt-devel
%endif
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  libjpeg-devel
BuildRequires:  python3-devel
%if %{with openmpi}
BuildRequires:  openmpi-devel
BuildRequires:  metis-devel
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat) 
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif
%if %{with need_clang}
BuildRequires:  llvm-clang
BuildRequires:  llvm
%else
%if %{?suse_version} == 1315
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++ >= 7
%endif
%endif
BuildRequires:  xz

%description
NETGEN is an automatic 3D tetrahedral mesh generator. It accepts
input from constructive solid geometry (CSG) or boundary
representation (BRep) from STL file format. The connection to a
geometry kernel allows the handling of IGES and STEP files. NETGEN
contains modules for mesh optimization and hierarchical mesh
refinement.

%package devel
Summary:        Development files for netgen
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
%if %{with opencascade}
Requires:       occt-devel
%endif

%description devel
Development files for NETGEN.


%prep
%setup -q
%patch0 -p1
%patch1 -p1
# fix version, non-number will break FreeCAD macros
sed -i -e 's,"6.2-dev","6.2.0",' libsrc/include/mydefs.hpp

%build
%if %{?suse_version} == 1315
export CC=gcc-7
export CXX=g++-7
%endif
mkdir build
cd build
%if %{with need_clang}
    OPTFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g") -flto"
%else
    OPTFLAGS="%{optflags}"
%endif
  CFLAGS="$OPTFLAGS -fno-strict-aliasing" \
  CXXFLAGS="$OPTFLAGS -fno-strict-aliasing" \
  cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DNG_INSTALL_DIR_INCLUDE=%{_includedir}/netgen \
    -DNG_INSTALL_DIR_LIB=%{_libdir}/netgen \
    -DCMAKE_SKIP_BUILD_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
%if %{with need_clang}
    -DCMAKE_C_COMPILER=clang \
    -DCMAKE_CXX_COMPILER=clang++ \
    -DCMAKE_AR=%{_bindir}/llvm-ar \
    -DCMAKE_RANLIB=%{_bindir}/llvm-ranlib \
    -DCMAKE_NM=%{_bindir}/llvm-nm \
    -DCMAKE_OBJDUMP=%{_bindir}/llvm-objdump \
%endif
    -DUSE_NATIVE_ARCH=OFF \
    -DUSE_GUI=ON \
    -DUSE_PYTHON=ON \
%if %{with openmpi}
    -DUSE_MPI=ON \
%else
    -DUSE_MPI=OFF \
%endif
    -DUSE_OCC=%{?with_opencascade:ON}%{!?with_opencascade:OFF} \
    -DUSE_JPEG=ON \
%if %{with ffmpeg}
    -DUSE_MPEG=ON \
%else
    -DUSE_MPEG=OFF \
%endif
    ..
  make %{?_smp_mflags}
cd ..

%install
cd build
%make_install
cd ..
%fdupes %{buildroot}/%{_prefix}

%files
%license LICENSE
%{_bindir}/*
%{_datadir}/netgen
%{_libdir}/netgen
%{python3_sitearch}/netgen

%files devel
%dir %{_prefix}/lib/cmake
%{_includedir}/netgen
%{_prefix}/lib/cmake/netgen

%changelog
* Thu Mar 21 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on ARM and PPC, only include immintrin.h when SSE is available
* Mon Mar 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct License:, netgen has always been LGPL-2.1-only.
- Package License file.
- Remove boost BuildRequires:, it is not used at all.
- Guard Requires: occt-devel in devel package with bcond, so it
  does not get pulled in if netgen is built without OpenCascade.
* Mon Mar 18 2019 Adrian Schröter <adrian@suse.de>
- switch to gcc7
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Remove ldconfig calls since there are only dlopened plugins,
  no standard libraries.
- Wrap description.
- Use convenient %%make_install, and run fdupes.
* Mon Mar 18 2019 Adrian Schröter <adrian@suse.de>
- update to version 6.2.1810
  obsoletes:
    allow_fine_curves.patch
    occ-pi-constant.patch
    do_stl_init.patch
- switch to cmake, obsoletes AM_PROG_AR.patch
- use obs_scm, obsoletes svnfetch.sh and netgen.sh
* Fri Dec  8 2017 adrian@suse.de
- move include files into /usr/include/netgen/
- use -fno-strict-aliasing
- add some extra header wrapper files missed by FreeCAD
* Tue Nov  7 2017 adrian@suse.de
- switch to OpenCASCADE 7.2.0
* Fri Jul 28 2017 adrian@suse.de
- switch to OpenCASCADE 7.1.0 and newer boost
* Tue Jan 31 2017 adrian@suse.de
- enable python for openSUSE Tumbleweed
* Mon Jun 13 2016 adrian@suse.de
- Using source service to follow git master (pre-6.1)
- use new oce instead of OpenCASCADE
- enable openmpi
- use fixes for rpath from Johannes Obermayer
  Sun Jan 23 2014 Torben Hansen <build at sciomnis dot com>
- Changed to upstream version
* Sun Mar 10 2013 jw@suse.com
- /usr/bin/netgen was a policy violation, -> /usr/lib/netgen
- Pulling git snapshot 5.1-dev, as the official 5.0.0 release only compiles
  with _MSC_VER; Ng_stl_Init() missing otherwise
- added full autoconf tooling to spec-file, sigh...
- renamed /usr/bin/netgen.sh to /usr/bin/netgen
* Sun Mar 10 2013 jw@suse.com
- update to 5.0.0
  * upstream changelog is empty
- obsolete fully upstreamed occ-6.5.0 patch
- patching ng/Makefile to find -lTogl1.7
- improved netgen.sh to allow parameters and preserve cwd.
- allow_fine_curves.patch added, finer defaults, extended slider range
* Sun Mar 18 2012 scorot@free.fr
- remove unneeded lam and lam-devel package requirement
* Tue May 31 2011 Werner Hoch <werner.ho@gmx.de>
- new version 4.9.13
- added patch occ-6.5.0.patch taken from debian package
  Sat Mar 27 16:46:40 CET 2010
- fixed compiling errors on gcc44
* Fri Oct 16 2009 andrea@opensuse.org
- new upstream version 4.9.11
* Wed Jun 10 2009 andrea@opensuse.org
- new upstream version
